ApplicationContext class

@author: cairuoyu @homepage: http://cairuoyu.com @github: https://github.com/cairuoyu/cry、https://github.com/cairuoyu/flutter_admin @date: 2021/6/21 @version: 1.0 @description:

Properties

beanMap ↔ Map
getter/setter pair
cameras ↔ List<CameraDescription>
getter/setter pair
faceDetector ↔ FaceDetector
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
privacy ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variableMap ↔ Map
getter/setter pair
yamlMap ↔ YamlMap
getter/setter pair

Methods

addBean(String key, dynamic object) → dynamic
convertVariable(dynamic key, dynamic value) → MapEntry
getBean(String key) → dynamic
init() → dynamic
loadApplication() → dynamic
loadPrivacy() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseCryProperties() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → ApplicationContext
no setter