ApiProperties class

Constructors

ApiProperties({String? baseUrl, int? connectTimeout, int? receiveTimeout})
ApiProperties.fromMap(Map map)
factory

Properties

baseUrl ↔ String?
getter/setter pair
connectTimeout ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
receiveTimeout ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? baseUrl, int? connectTimeout, int? receiveTimeout}) → ApiProperties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override