CascadeModel class

Constructors

CascadeModel({required String code, required String name, List<CascadeModel>? children})
CascadeModel.fromMap(Map<String, dynamic> map)
factory

Properties

children ↔ List<CascadeModel>?
getter/setter pair
code ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({required String code, required String name, List<CascadeModel>? children}) → CascadeModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override