ImageModel class

Constructors

ImageModel({String? title, String? url, String? categoryId, String? thumbs, String? memo, String? createTime})
ImageModel.fromJson(String source)
factory
ImageModel.fromMap(Map<String, dynamic> map)
factory

Properties

categoryId ↔ String?
getter/setter pair
createTime ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
memo ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbs ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair
url ↔ String?
getter/setter pair

Methods

copyWith({String? title, String? url, String? categoryId, String? thumbs, String? memo, String? createTime}) → ImageModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override