LoggerProperties class

Constructors

LoggerProperties({required String level})
LoggerProperties.fromMap(Map map)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
level ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? level}) → LoggerProperties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override