OrderItemModel class

Constructors

OrderItemModel({String? column, bool? asc})
OrderItemModel.fromJson(String source)
factory
OrderItemModel.fromMap(Map<String, dynamic> map)
factory

Properties

asc ↔ bool?
getter/setter pair
column ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? column, bool? asc}) → OrderItemModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override