PageModel class

Constructors

PageModel({int total = 0, int size = 10, int current = 1, int pages = 1, List<OrderItemModel> orders = const [], List<Map<String, dynamic>> records = const []})
PageModel.fromJson(String source)
factory
PageModel.fromMap(Map<String, dynamic> map)
factory

Properties

current ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
orders ↔ List<OrderItemModel>
getter/setter pair
pages ↔ int
getter/setter pair
records ↔ List<Map<String, dynamic>>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int
getter/setter pair
total ↔ int
getter/setter pair

Methods

copyWith({int? total, int? size, int? current, int? pages, List<OrderItemModel>? orders, List<Map<String, dynamic>>? records}) → PageModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override