RequestBodyApi class

Constructors

RequestBodyApi({PageModel? page, Map? params})
RequestBodyApi.fromJson(String source)
factory
RequestBodyApi.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
page ↔ PageModel?
getter/setter pair
params ↔ Map?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({PageModel? page, Map? params}) → RequestBodyApi
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override