TestTreeModel class

Inheritance

Constructors

TestTreeModel({String? id, String? pid, bool? checked, String? c1, String? c2})
TestTreeModel.fromJson(String source)
factory
TestTreeModel.fromMap(Map<String, dynamic> map)
factory

Properties

c1 ↔ String?
getter/setter pair
c2 ↔ String?
getter/setter pair
checked ↔ bool?
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
getter/setter pairoverride
pid ↔ String?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, String? pid, bool? checked, String? c1, String? c2}) → TestTreeModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override