CryUtils class

Constructors

CryUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

loadingOE ↔ OverlayEntry?
getter/setter pair

Static Methods

getCryProperties() → CryProperties
loaded() → void
loading({bool tapClose = false}) → void
message(String message, {int duration = 2}) → void