HttpUtil class

Constructors

HttpUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

dio ↔ Dio?
getter/setter pair

Static Methods

clear() → dynamic
createInstance() → Dio?
get(String url, {dynamic data, dynamic requestToken = true}) → Future<ResponseBodyApi>
post(String url, {dynamic data, dynamic requestToken = true}) → Future<ResponseBodyApi>
request(String url, {dynamic data, dynamic method, dynamic requestToken = true}) → Future<ResponseBodyApi>

Constants

GET → const String
POST → const String