TreeVO<T extends TreeData> class

Constructors

TreeVO({T? data})

Properties

checked ↔ bool?
getter/setter pair
children ↔ List<TreeVO<T>>
getter/setter pair
data ↔ T?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ IconData
getter/setter pair
isExpanded ↔ bool
getter/setter pair
parent ↔ TreeVO<T>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited